==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lv/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Apstiprināt lielapjoma aktīvu dzēšanu',
  'bulk_delete_help'	=> 'Pārskatīt aktīvu lielapjoma dzēšanu zemāk. Dzēstos aktīvus var atjaunot, bet tie vairs nebūs saistīti ar šībrīža lietotāju.',
  'bulk_delete_warn'	=> 'Jūs gatavojaties dzēst: asset_count aktīvi.',
	'bulk_update'		=> 'Lielapjoma atjaunināšanas līdzekļi',
	'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus aktīvus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
	'bulk_update_warn'	=> 'Jūs gatavojaties rediģēt: asset_count īpašumus.',
    'checkedout_to'		=> 'Izrakstīts uz',
    'checkout_date'		=> 'Izrakstīšanās datums',
    'checkin_date'		=> 'Reģistrēšanās datums',
    'checkout_to'		=> 'Izrakstīšanās līdz',
    'cost'				=> 'Iegādes izmaksas',
    'create'			=> 'Izveidot īpašumu',
    'date'				=> 'Pirkuma datums',
    'depreciation'	    => 'Nolietojums',
    'depreciates_on'	=> 'Atbalstīts ieslēgts',
    'default_location'	=> 'Noklusējuma atrašanās vieta',
    'eol_date'			=> 'EOL datums',
    'eol_rate'			=> 'EOL likme',
    'expected_checkin'  => 'Paredzamais reģistrēšanās datums',
    'expires'			=> 'Beidzas',
    'fully_depreciated'	=> 'Pilnībā nolietota',
    'help_checkout'		=> 'Ja vēlaties piešķirt šo priekšmetu uzreiz, atlasiet "Gatavs izvietošanai" no iepriekšējā statusa saraksta.',
    'mac_address'		=> 'MAC adrese',
    'manufacturer'		=> 'Ražotājs',
    'model'				=> 'Modelis',
    'months'			=> 'mēneši',
    'name'				=> 'Aktīva nosaukums',
    'notes'				=> 'Piezīmes',
    'order'				=> 'Pasūtījuma numurs',
    'qr'				=> 'QR kods',
    'requestable'		=> 'Lietotāji var pieprasīt šo aktīvu',
    'select_statustype'	=> 'Atlasiet statusa veidu',
    'serial'			=> 'Sērijas numurs',
    'status'			=> 'Statuss',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Aktīvu atjaunošana',
    'warranty'			=> 'Garantija',
		'warranty_expires'		=> 'Garantija beidzās',
    'years'				=> 'gadiem',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lv/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Apstiprināt lielapjoma aktīvu dzēšanu',
  'bulk_delete_help'	=> 'Pārskatīt aktīvu lielapjoma dzēšanu zemāk. Dzēstos aktīvus var atjaunot, bet tie vairs nebūs saistīti ar šībrīža lietotāju.',
  'bulk_delete_warn'	=> 'Jūs gatavojaties dzēst: asset_count aktīvi.',
    'bulk_update'		=> 'Lielapjoma atjaunināšanas līdzekļi',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus aktīvus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'bulk_update_warn'	=> 'Jūs gatavojaties rediģēt: asset_count īpašumus.',
    'checkedout_to'		=> 'Izrakstīts uz',
    'checkout_date'		=> 'Izrakstīšanās datums',
    'checkin_date'		=> 'Reģistrēšanās datums',
    'checkout_to'		=> 'Izrakstīšanās līdz',
    'cost'				=> 'Iegādes izmaksas',
    'create'			=> 'Izveidot īpašumu',
    'date'				=> 'Pirkuma datums',
    'depreciation'	    => 'Nolietojums',
    'depreciates_on'	=> 'Atbalstīts ieslēgts',
    'default_location'	=> 'Noklusējuma atrašanās vieta',
    'eol_date'			=> 'EOL datums',
    'eol_rate'			=> 'EOL likme',
    'expected_checkin'  => 'Paredzamais reģistrēšanās datums',
    'expires'			=> 'Beidzas',
    'fully_depreciated'	=> 'Pilnībā nolietota',
    'help_checkout'		=> 'Ja vēlaties piešķirt šo priekšmetu uzreiz, atlasiet "Gatavs izvietošanai" no iepriekšējā statusa saraksta.',
    'mac_address'		=> 'MAC adrese',
    'manufacturer'		=> 'Ražotājs',
    'model'				=> 'Modelis',
    'months'			=> 'mēneši',
    'name'				=> 'Aktīva nosaukums',
    'notes'				=> 'Piezīmes',
    'order'				=> 'Pasūtījuma numurs',
    'qr'				=> 'QR kods',
    'requestable'		=> 'Lietotāji var pieprasīt šo aktīvu',
    'select_statustype'	=> 'Atlasiet statusa veidu',
    'serial'			=> 'Sērijas numurs',
    'status'			=> 'Statuss',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Aktīvu atjaunošana',
    'warranty'			=> 'Garantija',
        'warranty_expires'		=> 'Garantija beidzās',
    'years'				=> 'gadiem',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
